pub struct CskkDictionary { /* private fields */ }Implementations
Sourceimpl CskkDictionary
impl CskkDictionary
Sourcepub fn new_static_dict(
file_path: &str,
encode: &str,
is_completable: bool,
) -> Result<CskkDictionary, CskkError>
pub fn new_static_dict( file_path: &str, encode: &str, is_completable: bool, ) -> Result<CskkDictionary, CskkError>
Library user interface for creating new static read-only dictionary. file_path: path string encode: label of encoding that encoding_rs can recognize. “utf-8”, “euc-jp”, “cp866” etc.
Sourcepub fn new_user_dict(
file_path: &str,
encode: &str,
is_completable: bool,
) -> Result<CskkDictionary, CskkError>
pub fn new_user_dict( file_path: &str, encode: &str, is_completable: bool, ) -> Result<CskkDictionary, CskkError>
Library user interface for creating new user readable and writable dictionary file_path: path string encode: label of encoding that encoding_rs can recognize. “utf-8”, “euc-jp”, “cp866” etc.
Sourcepub fn new_empty_dict() -> Result<CskkDictionary, CskkError>
pub fn new_empty_dict() -> Result<CskkDictionary, CskkError>
Library user interface for creating fallback dictionary. Dictionary is required to create the context, so this dictionary is useful when no dictionary file is available.